<?php

declare(strict_types=1);

namespace Drupal\navigation_plus\Plugin\Tool;

use Drupal\user\Entity\User;
use Drupal\navigation_plus\Attribute\Tool;
use Drupal\navigation_plus\ToolPluginBase;
use Drupal\navigation_plus\ToolPluginManager;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the tool.
 */
#[Tool(
  id: 'pointer',
  label: new TranslatableMarkup('Preview'),
  hot_key: 'p',
  weight: 0,
)]
final class Pointer extends ToolPluginBase {

  use StringTranslationTrait;

  public function __construct(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, ModuleExtensionList $extensionList, protected ToolPluginManager $toolManager, protected AccountProxyInterface $account) {
    parent::__construct($container, $configuration, $plugin_id, $plugin_definition, $extensionList);
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static (
      $container,
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('extension.list.module'),
      $container->get('plugin.manager.tools'),
      $container->get('current_user'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getIconsPath(): array {
    $path = $this->extensionList->getPath('navigation_plus');
    return [
      'toolbar_button_icons' => [
        'pointer' => "/$path/assets/cursor.svg",
        'refresh' => "/$path/assets/refresh.svg",
        'save' => "/$path/assets/save.svg",
        'discard-changes' => "/$path/assets/discard-changes.svg",
        'settings' => "/$path/assets/gear.svg",
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildSettings(): array {
    $tools = $this->toolManager->getTools();
    $user_hotkey_settings = [];
    if ($this->account->isAuthenticated()) {
      $user = User::load($this->account->id());
      $navigation_plus_settings = $user->navigation_plus_settings->getValue();
      if (!empty($navigation_plus_settings[0]['hotkeys'])) {
        $user_hotkey_settings = $navigation_plus_settings[0]['hotkeys'];
      }
    }
    $hot_keys_list = [];
    $hot_keys_settings = [];
    foreach ($tools as $id => $tool) {
      $hot_key = $user_hotkey_settings[$id] ?? $tool->hotKey();
      $hot_keys_settings[$id] = $hot_key;
      $hot_keys_list[$id]['#markup'] = sprintf('<div class="configured-hotkey-wrapper">%s <div class="configured-hotkey" data-tool-id="%s">%s</div></div>', $tool->label(), $id, strtoupper($hot_key));
    }
    $show_all_hotkey = !empty($user_hotkey_settings['show_all']) ? strtoupper($user_hotkey_settings['show_all']) : 'A';
    $hot_keys_list['show_all']['#markup'] = sprintf('<div class="configured-hotkey-wrapper">%s <div class="configured-hotkey" data-tool-id="%s">%s</div></div>', $this->t('Show All (Hold)'), 'show_all', $show_all_hotkey);
    $hot_keys_settings['show_all'] = $user_hotkey_settings['show_all'] ?? 'a';

    return [
      'hotkeys' => [
        '#type' => 'details',
        '#title' => $this->t('Hotkeys'),
        '#open' => FALSE,
        '#attributes' => [
          'class' => ['hotkeys-details'],
        ],
        '#attached' => ['drupalSettings' => ['navigationPlus' => ['hotKeys' => $hot_keys_settings]]],
        'current_hotkeys' => [
          '#theme' => 'item_list',
          '#items' => $hot_keys_list,
          '#attributes' => [
            'class' => ['hotkeys-list'],
          ],
        ],
      ],
    ];
  }

}
